/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Interface used to interact with the second-level cache.
/// If a cache is not in use, the methods of this interface have
/// no effect, except for <c>contains</c>, which returns false.
/// 
/// 
/// </summary>
public interface Cache {

    /// <summary> Whether the cache contains data for the given entity.
    /// <param name="cls">  entity class </param>
    /// <param name="primaryKey">  primary key</param>
    /// <returns> boolean indicating whether the entity is in the cache</returns>
    /// </summary>
    bool Contains(System.Type cls, object primaryKey);

    /// <summary> Remove the data for the given entity from the cache.
    /// <param name="cls">  entity class</param>
    /// <param name="primaryKey">  primary key</param>
    /// </summary>
    void Evict(System.Type cls, object primaryKey);

    /// <summary> Remove the data for entities of the specified class (and its
    /// subclasses) from the cache.
    /// <param name="cls">  entity class</param>
    /// </summary>
    void Evict(System.Type cls);

    /// <summary> Clear the cache.
    /// </summary>
    void EvictAll();
}
}