﻿using System;
using System.Configuration;

namespace NPersistence
{
    /// <summary>
    /// This interface is used for configuring NPersistence inside a web application.
    /// Inside a web application the NPersistence configuration is done as follows:
    /// <ul>
    /// <li>
    /// The 'persistence-unit' xml tag that configures NPersistence (which is usualy placed inside the persistence.xml file), should be placed in the 'Web.config' file.
    /// </li>
    /// <li>
    /// The 'configSections' tag inside the Web.config file should mention 'NPersistence.ConfigurationSectionHandler' as one of the sections.
    /// </li>
    /// </ul>
    /// 
    /// <example>
    /// <code>
    /// 
    /// &lt;configuration&gt;
    /// ...
    ///   &lt;configSections&gt;
    ///     &lt;section name="persistence-unit"
    ///              type="NPersistence.ConfigurationSectionHandler, NPersistence" /&gt;
    ///   &lt;/configSections&gt;
    /// ...
    ///      &lt;persistence-unit name="examplePersistenceUnit"&gt;
    ///    &lt;provider&gt;NPersistence.NHibernate.NHibernatePersistence&lt;/provider&gt;
    ///      &lt;class&gt;tests.Employee&lt;/class&gt;
    ///    &lt;properties&gt;
    ///      &lt;property name="connection.provider" value="NHibernate.Connection.DriverConnectionProvider"/&gt;
    ///      &lt;property name="dialect" value="NHibernate.Dialect.MySQL5Dialect"/&gt;
    ///      &lt;property name="connection.driver_class" value="NHibernate.Driver.MySqlDataDriver"/&gt;
    ///      &lt;property name="connection.connection_string" value="server=srvName; user id=usrName; password=pass; database=test"/&gt;
    ///    &lt;/properties&gt;
    ///  &lt;/persistence-unit&gt;
    /// </code>
    /// </example>
    /// </summary>
    public class ConfigurationSectionHandler : IConfigurationSectionHandler
    {
        object System.Configuration.IConfigurationSectionHandler.Create(object parent, object configContext, System.Xml.XmlNode section)
        {
            return section;
        }
    }
}
