/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

    /// <summary> Specifies a persistent field or property of an entity whose 
    /// value is an instance of an embeddable class. The embeddable 
    /// class must be annotated as <see cref="Embeddable"/>.
    ///<para>
    ///  The <c>AttributeOverride</c> and <c>AssociationOverride</c>
    /// annotations may be used to override mappings declared or defaulted
    /// by the embeddable class.
    /// </para>
    /// <example><code>
    ///   Example:
    /// 
    ///   &#91;Embedded&#93;
    ///   &#91;AttributeOverride(PropertyName="startDate", Name="EMP_START")&#93;
    ///   &#91;AttributeOverride(PropertyName="endDate", Name="EMP_END")&#93;
    ///   public EmploymentPeriod getEmploymentPeriod() { ... }
    /// </code></example>
    /// 
    /// <seealso cref="Embeddable"/>
    /// <seealso cref="AttributeOverride"/>
    /// <seealso cref="AssociationOverride"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]


public sealed class Embedded : System.Attribute {
}
}