/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;

/// <summary> Thrown by the persistence provider when an entity reference obtained by
/// <see cref="EntityManager.GetReference"/>
/// is accessed but the entity does not exist. 
    /// <para>
/// Thrown when
/// <see cref="EntityManager.Refresh"/> is called and the
/// object no longer exists in the database. 
    /// </para>
    /// <para>
/// Thrown when <see cref="EntityManager.Lock"/> is used with
/// pessimistic locking is used and the entity no longer exists in the database.
///  The current transaction, if one is active, will be marked for rollback.
/// </para>
/// <seealso cref="EntityManager.GetReference(Type,Object)"/>
/// <seealso cref="EntityManager.Refresh(Object)"/>
/// <seealso cref="EntityManager.Refresh(Object, LockModeType)"/>
/// <seealso cref="M:EntityManager.Refresh(Object, T:Dictionary`2)"/>
    /// <seealso cref="M:EntityManager.Refresh(Object, LockModeType, T:Dictionary`2)"/>
/// <seealso cref="EntityManager.Lock(Object, LockModeType)"/>
/// <seealso cref="M:EntityManager.Lock(Object, LockModeType, T:Dictionary`2)"/>
/// 
/// 
/// </summary>
public class EntityNotFoundException : PersistenceException {

	/// <summary> Constructs a new <c>EntityNotFoundException</c> exception with
	/// <c>null</c> as its detail message.
	/// </summary>
	public EntityNotFoundException() : base() {
		// super(...) -> base(...)
	}

	/// <summary> Constructs a new <c>EntityNotFoundException</c> exception with the
	/// specified detail message.
	/// </summary>
	/// <param name="message">
    ///            the detail message.</param>
	/// 
	public EntityNotFoundException(string message) : base(message) {
		// super(...) -> base(...)
	}

}
}