/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



    /// <summary> Used to map the SELECT clause of a SQL query to an entity result.
    /// If this annotation is used, the SQL statement should select 
    /// all of the columns that are mapped to the entity object. 
    /// <para>
    /// This should include foreign key columns to related entities. 
    /// The results obtained when insufficient data is available 
    /// are undefined.
    /// </para>
    /// <example><code>
    ///   Example:
    /// 
    ///   Query q = em.createNativeQuery(
    ///       "SELECT o.id, o.quantity, o.item, i.id, i.name, i.description "+
    ///           "FROM Order o, Item i " +
    ///           "WHERE (o.quantity > 25) AND (o.item = i.id)",
    ///       "OrderItemResults");
    ///   &#91;SqlResultSetMapping(name="OrderItemResults")&#93;
    ///           &#91;EntityResult(ResultSetRef = "OrderItemResults", entityClass=com.acme.Order.class)&#93;
    ///           &#91;EntityResult(ResultSetRef = "OrderItemResults", entityClass=com.acme.Item.class)&#93;
    /// </code></example>
    /// 
    /// <seealso cref="SqlResultSetMapping"/>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Class, AllowMultiple = true)]
    public sealed class EntityResult : System.Attribute 
    {
        /// <summary>
        /// Required
        /// Name of this EntityResult, the name is used by FieldResults to reference this object.
        /// </summary>
        public String Name;
    
        /// <summary>
        /// Required.
        /// Points to the SqlResultSetMapping this EntityResult belongs to.
        /// </summary>
        public String ResultSetRef;

        /// <summary> The class of the result.
    /// </summary>
        public System.Type EntityClass; 

        /// <summary> 
        /// Specifies the column name (or alias) of the column in 
        /// the SELECT list that is used to determine the type of 
        /// the entity instance.
        /// </summary>
        public string DiscriminatorColumn = "";
    }
}