/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;



/// <summary> Interface for extracting the elements of a query result tuple.
/// 
/// <seealso cref="T:NPersistence.TupleElement`1"/>
/// 
/// 
/// </summary>
public interface Tuple {

    /// <summary> Get the value of the specified tuple element.
    /// <param name="tupleElement">  tuple element</param>
    /// <returns> value of tuple element</returns>
    /// <exception cref="ArgumentException"> if tuple element
    ///         does not correspond to an element in the
    ///         query result tuple</exception>
    /// </summary>
    X Get<X> (TupleElement<X> tupleElement);

    /// <summary> Get the value of the tuple element to which the
    /// specified alias has been assigned.
    /// <param name="alias">  alias assigned to tuple element</param>
    /// <param name="type"> of the tuple element</param>
    /// <returns> value of the tuple element</returns>
    /// <exception cref="ArgumentException"> if alias
    ///         does not correspond to an element in the
    ///         query result tuple or element cannot be
    ///         assigned to the specified type</exception>
    /// </summary>
    X Get<X> (string alias, System.Type type); 

    /// <summary> Get the value of the tuple element to which the
    /// specified alias has been assigned.
    /// <param name="alias">  alias assigned to tuple element</param>
    /// <returns> value of the tuple element</returns>
    /// <exception cref="ArgumentException"> if alias
    ///         does not correspond to an element in the
    ///         query result tuple</exception>
    /// </summary>
    object Get(string alias); 

    /// <summary> Get the value of the element at the specified
    /// position in the result tuple. The first position is 0.
    /// <param name="i">  position in result tuple</param>
    /// <param name="type">  type of the tuple element</param>
    /// <returns> value of the tuple element</returns>
    /// <exception cref="ArgumentException"> if i exceeds
    ///         length of result tuple  or element cannot be
    ///         assigned to the specified type</exception>
    /// </summary>
    X Get<X> (int i, System.Type type);

    /// <summary> Get the value of the element at the specified
    /// position in the result tuple. The first position is 0.
    /// <param name="i">  position in result tuple</param>
    /// <returns> value of the tuple element</returns>
    /// <exception cref="ArgumentException"> if i exceeds
    ///         length of result tuple</exception>
    /// </summary>
    object Get(int i);

    /// <summary> Return the values of the result tuple elements as an array.
    /// <returns> tuple element values</returns>
    /// </summary>
    object[] ToArray();

    /// <summary> Return the tuple elements.
    /// <returns> tuple elements</returns>
    /// </summary>
    IList<TupleElement<object>> GetElements();
}
}