/*****************************************************************************
/// Copyright (c) 2008, 2009 Sun Microsystems. All rights reserved. 
/// 
/// This program and the accompanying materials are made available under the 
/// terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0 
/// which accompanies this distribution. 
/// The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
/// and the Eclipse Distribution License is available at 
/// http://www.eclipse.org/org/documents/edl-v10.php.
/// 
/// Contributors:
///     Linda DeMichiel - Java Persistence 2.0 - Version 2.0 (October 1, 2009)
///     Specification available from http://jcp.org/en/jsr/detail?id=317
/// 
/*****************************************************************************/
namespace NPersistence { using System; using System.Reflection; using System.Collections; using System.Collections.Generic;


    /// <summary> Specifies the version field or property of an entity class that
    /// serves as its optimistic lock value. 
    /// <para>
    /// The version is used to ensure
    /// integrity when performing the merge operation and for optimistic
    /// concurrency control.
    /// </para><para>
    ///  Only a single <c>Version</c> property or field 
    /// should be used per class; applications that use more than one 
    /// <c>Version</c> property or field will not be portable. 
    /// </para><para>
    ///  The <c>Version</c> property should be mapped to 
    /// the primary table for the entity class; applications that 
    /// map the <c>Version</c> property to a table other than 
    /// the primary table will not be portable.
    /// </para><para>
    ///  The following types are supported for version properties: 
    ///  </para><para>
    /// <c>int</c>, 
    /// </para><para>
    /// <c>Integer</c>,
    /// </para><para>
    /// <c>short</c>,
    /// </para><para>
    /// <c>Short</c>,
    /// </para><para>
    /// <c>long</c>,
    /// </para><para>
    /// <c>Long</c>, 
    /// </para><para>
    /// <c>System.Data.DbType.Timestamp</c>.
    /// </para>
    /// <example><code>
    ///    Example:
    /// 
    ///    &#91;Version&#93;
    ///    &#91;Column(name="OPTLOCK")&#93;
    ///    protected int getVersionNum() { return versionNum; }
    /// </code></example>
    /// 
    /// 
    /// </summary>
    [System.AttributeUsage(System.AttributeTargets.Field | System.AttributeTargets.Property)]

public sealed class Version : System.Attribute {}
}